class DataDelayed {
    constructor() {
        this.tags = document.querySelectorAll("[data-delayed]");
        this.contentWrapper = document.querySelector('#contentWrap');
        this.cookieBannerElement = document.getElementById('ig_cookies_container');
        this.placeholder = this.generatePlaceholder();
        if (this.hasTags()) {
            this.loadTags();
        }
    }
    hasTags() {
        return this.tags.length > 0;
    }
    loadTags() {
        for (var i = 0; i < this.tags.length; i++) {
            // create object with init and update function for watcher
            let obj = {
                tag: this.tags[i],
                consent: this.tags[i].dataset.consent || 'needed',
                placeholder: this.getPlaceholder(),
                placeholderElement: null,
                update(consents) {
                    if (consents[this.consent]) {
                        let nodeName = this.tag.nodeName == "LINK" ? "href" : "src";
                        // replace data-delayed with src/href
                        this.tag.setAttribute(nodeName, this.tag.dataset.delayed);
                        // cleanup tag from attributes and classes
                        this.tag.removeAttribute("data-delayed");
                        this.tag.removeAttribute("data-consent");
                        this.tag.classList.remove("no-consent");
                        // remove placeholder if one is set
                        if (this.placeholderElement) {
                            this.placeholderElement.remove();
                        }
                    }
                },
                init(consents) {
                    // add placeholder element with cookie banner opener
                    if (!consents[this.consent] && document.querySelector('#contentWrap').contains(this.tag)) {
                        this.tag.after(this.placeholder);
                        this.placeholderElement = this.tag.nextElementSibling;
                        this.tag.classList.add("no-consent");
                    }
                }
            }
            // add object to watcher
            window.IgConsentManager.watch(obj);
        }
    }
    generatePlaceholder() {
        let container = document.createElement('div');
        let text = document.createElement('div');
        let a = document.createElement('a');
        text.innerHTML = this.cookieBannerElement.dataset.placeholdertext;
        a.innerHTML = this.cookieBannerElement.dataset.placeholderbuttontext;
        a.href = "#";
        container.append(text);
        container.append(a);
        return container;
    }
    getPlaceholder() {
        let container = this.placeholder.cloneNode(true);
        let link = container.getElementsByTagName('a')[0];
        link.addEventListener('click', (e) => {
            e.preventDefault();
            this.cookieBannerElement.removeAttribute('style');
        });
        return container;
    }
}
const dataDelayed = new DataDelayed();